## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# PackIt can't access this repo without opening the firewall
# global forgeurl https://git.skyjake.fi/gemini/lagrange
%global forgeurl https://github.com/skyjake/lagrange
%global appid fi.skyjake.Lagrange

# Ensure we are not built and installed with a too-old the_Foundation
%global min_foundation_ver 1.7.0

# this seems buggy on Wayland: see https://github.com/skyjake/lagrange/issues/575
%bcond_with x11_xlib

Name:           lagrange
Version:        1.18.5
Release:        %autorelease
Summary:        A Beautiful Gemini Client

License:        BSD-2-Clause
URL:            https://gmi.skyjake.fi/lagrange/
# Source:         %%{forgeurl}/releases/download/v%%{version}/%%{name}-%%{version}.tar.gz
Source:         %{forgeurl}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(libmpg123)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(the_Foundation) >= %{min_foundation_ver}
# for checks
BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib

Requires:       the_foundation%{_isa} >= %{min_foundation_ver}

%description
Lagrange is a desktop GUI client for browsing Geminispace. It offers modern
conveniences familiar from web browsers, such as smooth scrolling, inline image
viewing, multiple tabs, visual themes, Unicode fonts, bookmarks, history, and
page outlines.

Like Gemini, Lagrange has been designed with minimalism in mind. It depends on a
small number of essential libraries. It is written in C and uses SDL for
hardware-accelerated graphics. OpenSSL is used for secure communications.


%prep
%autosetup -p1
# remove bundled libs
rm -rf lib
%if 0%{?el8}
# EL8 appdata does not support this, remove
sed -i -e '/<url type="contact">/d' res/fi.skyjake.Lagrange.appdata.xml
%endif


%build
%cmake \
  -DENABLE_POPUP_MENUS:BOOL=NO \
%if %{without x11_xlib}
  -DENABLE_X11_XLIB:BOOL=NO \
%endif

%cmake_build


%install
%cmake_install


%check
desktop-file-validate \
  %{buildroot}/%{_datadir}/applications/%{appid}.desktop

appstream-util validate-relax --nonet \
  %{buildroot}%{_metainfodir}/%{appid}.appdata.xml


%files
%license LICENSE.md
%doc AUTHORS.md README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/icons/hicolor/256x256/apps/%{appid}.png
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/resources.lgr
%{_mandir}/man1/%{name}.1*
%{_metainfodir}/%{appid}.appdata.xml

%changelog
## START: Generated by rpmautospec
* Sun Mar 09 2025 Packit <hello@packit.dev> - 1.18.5-1
- Update to 1.18.5
- Resolves rhbz#2350955

* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.18.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Tue Dec 10 2024 Packit <hello@packit.dev> - 1.18.4-1
- Update to 1.18.4
- Resolves rhbz#2331412

* Mon Oct 14 2024 Packit <hello@packit.dev> - 1.18.3-1
- Update to 1.18.3
- Resolves rhbz#2313979

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.17.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Wed Mar 06 2024 Packit <hello@packit.dev> - 1.17.6-1
- Update to 1.17.6
- Resolves rhbz#2258919

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.17.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.17.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Dec 13 2023 Michel Lind <salimma@fedoraproject.org> - 1.17.5-1
- Update to 1.17.5

* Tue Aug 22 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.16.7-1
- Update to 1.16.7

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.15.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Fri Mar 10 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.15.4-1
- Update to 1.15.4

* Fri Feb 10 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.15.2-3
- Ensure we are not built and installed with a too-old the_Foundation

* Thu Feb 09 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.15.2-2
- Temporarily disable dark theme support to work around Wayland issue
- switch to using SPDX license identifier

* Thu Feb 09 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.15.2-1
- Update to 1.15.2

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.14.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jan 11 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.14.2-2
- Disable popup menus to work around SDL2's incomplete Wayland support

* Wed Jan 11 2023 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.14.2-1
- Update to 1.14.2

* Wed Aug 03 2022 Michel Alexandre Salim <michel@michel-slm.name> - 1.13.7-1
- Update to 1.13.7

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.13.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Jun 02 2022 Yizheng Xie <yizhengxie@fb.com> - 1.13.6-1
- Update to 1.13.6

* Thu May 19 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.13.5-1
- Update to 1.13.5

* Mon May 09 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.13.3-2
- Build with optional mp3 and webp support

* Mon May 09 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.13.3-1
- Update to 1.13.3

* Thu May 05 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.13.2-1
- Update to 1.13.2

* Fri Apr 08 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.12.1-1
- Update to 1.12.1

* Mon Mar 21 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.11.2-1
- Update to 1.11.2

* Mon Mar 07 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.11.1-2
- Bump for the_foundation SOVERSION change

* Sun Mar 06 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.11.1-1
- Update to 1.11.1 (resolves: rhbz#2056199)

* Fri Feb 11 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.10.5-1
- Update to 1.10.5

* Tue Feb 08 2022 Michel Alexandre Salim <salimma@fedoraproject.org> - 1.10.4-1
- Initial Fedora package
## END: Generated by rpmautospec
